@@ -2,7 +2,6 @@ package ExtUtils::Typemaps::OutputMap;
 use 5.006001;
 use strict;
 use warnings;
-our $VERSION = '3.43_02';
 
 =head1 NAME
 
@@ -95,23 +94,16 @@ sub cleaned_code {
 
 =head2 targetable
 
-This is an obscure but effective optimization that used to
-live in C<ExtUtils::ParseXS> directly. Not implementing it
-should never result in incorrect use of typemaps, just less
-efficient code.
+This is an obscure optimization that used to live in C<ExtUtils::ParseXS>
+directly.
 
 In a nutshell, this will check whether the output code
-involves calling C<sv_setiv>, C<sv_setuv>, C<sv_setnv>, C<sv_setpv> or
-C<sv_setpvn> to set the special C<$arg> placeholder to a new value
+involves calling C<set_iv>, C<set_uv>, C<set_nv>, C<set_pv> or C<set_pvn>
+to set the special C<$arg> placeholder to a new value
 B<AT THE END OF THE OUTPUT CODE>. If that is the case, the code is
 eligible for using the C<TARG>-related macros to optimize this.
 Thus the name of the method: C<targetable>.
 
-If this optimization is applicable, C<ExtUtils::ParseXS> will
-emit a C<dXSTARG;> definition at the start of the generated XSUB code,
-and type (see below) dependent code to set C<TARG> and push it on
-the stack at the end of the generated XSUB code.
-
 If the optimization can not be applied, this returns undef.
 If it can be applied, this method returns a hash reference containing
 the following information:
@@ -120,7 +112,7 @@ the following information:
   with_size: Bool indicating whether this is the sv_setpvn variant
   what:      The code that actually evaluates to the output scalar
   what_size: If "with_size", this has the string length (as code,
-             not constant, including leading comma)
+             not constant)
 
 =cut
 
@@ -136,13 +128,6 @@ sub targetable {
       \( (??{ $bal }) \)
     )*
   ]x;
-  my $bal_no_comma = qr[
-    (?:
-      (?>[^(),]+)
-      |
-      \( (??{ $bal }) \)
-    )+
-  ]x;
 
   # matches variations on (SV*)
   my $sv_cast = qr[
@@ -153,7 +138,7 @@ sub targetable {
 
   my $size = qr[ # Third arg (to setpvn)
     , \s* (??{ $bal })
-  ]xo;
+  ]x;
 
   my $code = $self->code;
 
@@ -169,10 +154,10 @@ sub targetable {
         \s*
         \( \s*
           $sv_cast \$arg \s* , \s*
-          ( $bal_no_comma )    # Set from
-          ( $size )?           # Possible sizeof set-from
-        \s* \) \s* ; \s* $
-      ]xo
+          ( (??{ $bal }) )    # Set from
+        ( (??{ $size }) )?    # Possible sizeof set-from
+        \) \s* ; \s* $
+      ]x
   );
 
   my $rv = undef;
