@@ -4,8 +4,6 @@ use strict;
 use warnings;
 require ExtUtils::Typemaps;
 
-our $VERSION = '3.43_02';
-
 =head1 NAME
 
 ExtUtils::Typemaps::Type - Entry in the TYPEMAP section of a typemap
@@ -53,7 +51,7 @@ sub new {
 
   $self->{xstype} = $args{xstype} if defined $args{xstype};
   $self->{ctype} = $args{ctype} if defined $args{ctype};
-  $self->{tidy_ctype} = ExtUtils::Typemaps::tidy_type($self->{ctype});
+  $self->{tidy_ctype} = ExtUtils::Typemaps::_tidy_type($self->{ctype});
   $self->{proto} = $args{'prototype'} if defined $args{'prototype'};
 
   return $self;
